package com.webchat.admin.service;

import com.webchat.common.bean.APIPageResponseBean;
import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.common.constants.WebConstant;
import com.webchat.common.enums.RedisKeyEnum;
import com.webchat.common.exception.BusinessException;
import com.webchat.domain.vo.request.CreatePublicAccountRequestVO;
import com.webchat.domain.vo.request.CreateRobotRequestVO;
import com.webchat.domain.vo.response.UserBaseResponseInfoVO;
import com.webchat.rmi.user.UserServiceClient;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

@Service
public class AccountManagementService {


    @Autowired
    private UserServiceClient userServiceClient;

    public APIPageResponseBean<UserBaseResponseInfoVO> page(String userId, Integer roleCode, String userName, String mobile, Integer pageNo, Integer pageSize) {

        return userServiceClient.page(userId, roleCode, userName, mobile, pageNo, pageSize);
    }

    /**
     * 创建机器人
     *
     * 复用用户信息表，账号角色为 ROBOT
     */
    public void createRobot(CreateRobotRequestVO requestPram) {
        APIResponseBean apiResponseBean = userServiceClient.createRobot(requestPram);
        if (APIResponseBeanUtil.isOk(apiResponseBean)) {
            return;
        }
        throw new BusinessException(apiResponseBean.getMsg());
    }

    /**
     * 创建公众号
     *
     * 复用用户信息表，账号角色为 PUBLIC_ACCOUNT
     */
    public void createPublicAccount(CreatePublicAccountRequestVO requestVO) {
        APIResponseBean apiResponseBean = userServiceClient.createPublicAccount(requestVO);
        if (APIResponseBeanUtil.isOk(apiResponseBean)) {
            return;
        }
        throw new BusinessException(apiResponseBean.getMsg());
    }

}
