package com.webchat.rmi.user;

import com.webchat.common.bean.APIPageResponseBean;
import com.webchat.common.bean.APIResponseBean;
import com.webchat.common.bean.APIResponseBeanUtil;
import com.webchat.common.helper.SessionHelper;
import com.webchat.domain.vo.request.CreatePublicAccountRequestVO;
import com.webchat.domain.vo.request.CreateRobotRequestVO;
import com.webchat.domain.vo.request.UserRegistryInfoRequestVO;
import com.webchat.domain.vo.response.UserBaseResponseInfoVO;
import com.webchat.domain.vo.response.UserBaseResponseVO;
import org.apache.el.parser.BooleanNode;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.Map;
import java.util.Set;

/**
 * @Author 程序员七七
 * @webSite https://www.coderutil.com
 * @Date 2025/1/14 00:51
 * @description
 */
@FeignClient(name = "webchat-user-service")
public interface UserServiceClient {

    /**
     * 查询用户详情
     *
     * @param userId 用户ID
     * @return
     */
    @GetMapping("/user-service/user/info/{userId}")
    APIResponseBean<UserBaseResponseInfoVO> userInfo(@PathVariable String userId);

    /**
     * 根据手机号查询用户基础信息
     *
     * @param mobile
     * @return
     */
    @GetMapping("/user-service/user/mobile/info/{mobile}")
    APIResponseBean<UserBaseResponseVO> userBaseInfo(@PathVariable String mobile);

    /**
     * 新账号注册
     *
     * @param request
     * @return
     */
    @PostMapping("/user-service/user/register")
    APIResponseBean<Boolean> registry(@RequestBody UserRegistryInfoRequestVO request);

    /**
     * 账号列表查询
     *
     * @param roleCode
     * @param userName
     * @param mobile
     * @param pageNo
     * @param pageSize
     * @return
     */
    @GetMapping("/user-service/account/page")
    APIPageResponseBean<UserBaseResponseInfoVO> page(
            @RequestParam(value = "userId", required = false) String userId,
            @RequestParam(value = "roleCode") Integer roleCode,
            @RequestParam(value = "userName", required = false) String userName,
            @RequestParam(value = "mobile", required = false) String mobile,
            @RequestParam(value = "pageNo", required = false, defaultValue = "1") Integer pageNo,
            @RequestParam(value = "pageSize", required = false, defaultValue = "10") Integer pageSize);


    /**
     * 创建机器人
     *
     * @return
     */
    @PostMapping("/user-service/account/createRobot")
    APIResponseBean createRobot(@RequestBody CreateRobotRequestVO requestPram);

    /**
     * 创建公众号
     * 默认只有管理员可以创建公众号
     *
     * @return
     */
    @PostMapping("/user-service/account/createPublicAccount")
    APIResponseBean createPublicAccount(@RequestBody CreatePublicAccountRequestVO requestPram);


    /**
     * 批量查询用户详情
     * 底层走Redis
     *
     * @param userIds
     * @return
     */
    @PostMapping("/user-service/account/batchGet")
    APIResponseBean<Map<String, UserBaseResponseInfoVO>> batchGet(@RequestBody Set<String> userIds);
}
